import { Continuable, ContinuableConstructorParams, FetchResult } from "../Continuable";
import { VideoCompact } from "../VideoCompact";
import { BaseChannel } from "./BaseChannel";
declare type ConstructorParams = ContinuableConstructorParams & {
    channel?: BaseChannel;
};
/**
 * {@link Continuable} of videos inside a {@link BaseChannel}
 *
 * @example
 * ```js
 * const channel = await youtube.findOne(CHANNEL_NAME, {type: "channel"});
 * await channel.live.next();
 * console.log(channel.live.items) // first 30 live videos
 *
 * let newLives = await channel.videos.next();
 * console.log(newLives) // 30 loaded live videos
 * console.log(channel.live.items) // first 60 live videos
 *
 * await channel.live.next(0); // load the rest of the live videos in the channel
 * ```
 */
export declare class ChannelLive extends Continuable<VideoCompact> {
    /** The channel this live videos belongs to */
    channel?: BaseChannel;
    /** @hidden */
    constructor({ client, channel }: ConstructorParams);
    protected fetch(): Promise<FetchResult<VideoCompact>>;
}
export {};
